==> icedove-dispmua_1.6.3.orig.tar.gz: icedove-dispmua-1.6.3/chrome/content/data-69.js <==
dispMUA.arDispMUAAllocation["i"] =
{
  "interfejs www nowej poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "interfejs www poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "ibm lotus domino access for ms outlook" : [ "domino_outlook.png" , "http://www-306.ibm.com/software/lotus/support/damo/use.html" ] ,
  "internetpost for active platform" : [ "internetpost.png" , "http://www.hitachi-to.co.jp/prod/prod_2/inter/ip4ap/overview.html" ] ,
  "internet messaging program" : [ "horde.png" , "http://www.horde.org/imp/" ] ,
  "iskoninternet webmail" : [ "iskon.png" , "http://webmail.iskon.hr/" ] ,
  "internet mail service" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "ipx-manager via php" : [ "ipxserver.png" , "http://www.ipx-server.de/" ] ,
  "ibforums php mailer" : [ "ipb.png" , "http://www.invisionpower.com/" ] ,
  "internet fax, mgcs" : [ "panafax.png" , "http://www.panasonic.com/business/office/pro_fax.asp" ] ,
  "ics smtp component" : [ "ics.png" , "http://www.overbyte.be/" ] ,
  "internet anywhere" : [ "internet-anywhere.png" , "http://www.tnsoft.de/" ] ,
  "inside-intermedia" : [ "inside-intermedia.png" , "http://www.inside-intermedia.de/" ] ,
  "i-base newsletter" : [ "i-base.png" , "http://www.i-base.net/" ] ,
  "inmail by insite" : [ "inmailinsite.png" , "http://inmail.insite.com.br/" ] ,
  "inbox.lv webmail" : [ "inbox.png" , "http://www.inbox.lv/" ] ,
  "inbox.lt webmail" : [ "inbox.png" , "http://www.inbox.lt/" ] ,
  "i.ua mail system" : [ "i_ua.png" , "http://www.i.ua/" ] ,
  "ixmailer (ken!)" : [ "ken.png" , "http://www.avm.de/" ] ,
  "ipb php mailer" : [ "ipb.png" , "http://www.invisionpower.com/" ] ,
  "ieurop webmail" : [ "ieurop_net.png" , "http://www.ieurop.net/" ] ,
  "inwise mailer" : [ "inwise.png" , "http://www.inwise.com/" ] ,
  "interact24.de" : [ "interact24_de.png" , "http://interact24.de/" ] ,
  "inteligo-smtp" : [ "inteligo.png" , "http://www.inteligo.pl/" ] ,
  "inmail insite" : [ "inmailinsite.png" , "http://inmail.insite.com.br/" ] ,
  "immsgmassmail" : [ "software_com.png" , "http://www.software.com/" ] ,
  "icompass-mail" : [ "icompass.png" , "http://www.identitycompass.com/" ] ,
  "i-soft/i-tems" : [ "i_tems.png" , "http://www.i-soft-net.de/" ] ,
  "i-soft i-tems" : [ "i_tems.png" , "http://www.i-soft-net.de/" ] ,
  "it&o-versand" : [ "itando.png" , "http://www.itando.net/versand.htm" ] ,
  "ihug webmail" : [ "ihug.png" , "http://webmail.ihug.co.nz/" ] ,
  "ientrymailer" : [ "ientrymailer.png" ] ,
  "iphone mail" : [ "apple_iphone.png" , "http://www.apple.com/" ] ,
  "incredimail" : [ "incredimail.png" , "http://www.incredimail.com/" ] ,
  "ipilum.com" : [ "ipilum_com.png" , "http://www.ipilum.com/" ] ,
  "infomaniak" : [ "infomaniak.png" , "http://www.infomaniak.ch/" ] ,
  "immonet.de" : [ "immonet_de.png" , "http://www.immonet.de/" ] ,
  "igraalmail" : [ "igraal.png" , "http://fr.igraal.com/" ] ,
  "ibr-online" : [ "ibr-online.png" , "http://www.ibr-online.de/" ] ,
  "irfanview" : [ "irfanview.png" , "http://www.irfanview.net/" ] ,
  "ipod mail" : [ "apple_ipodtouch.png" , "http://www.apple.com/" ] ,
  "iofficev3" : [ "iofficev3.png" , "http://www.neo.co.jp/ioffice/" ] ,
  "intellect" : [ "intellect.png" , "http://www.chaossoftware.com/intellect.asp" ] ,
  "indexsoft" : [ "indexsoft.png" , "http://www.indexsoft.com/" ] ,
  "incomedia" : [ "incomedia.png" , "http://www.incomedia.it/" ] ,
  "inbox.com" : [ "inbox_com.png" , "http://www.inbox.com/" ] ,
  "ilohamail" : [ "iloha_mail.png" , "http://ilohamail.org/" ] ,
  "ik mailer" : [ "ikmultimedia.png" , "http://www.ikmultimedia.com/" ] ,
  "ibwebmail" : [ "infobox_ru.png" , "http://www.infobox.ru/" ] ,
  "ironmail" : [ "securecomputing.png" , "http://www.ciphertrust.com/products/cclass/" ] ,
  "ippbxsrv" : [ "telekom.png" , "http://www.telekom.de/" ] ,
  "intouch/" : [ "claros_intouch.png" , "http://www.claros.org/" ] ,
  "inscribe" : [ "inscribe.png" , "http://www.memecode.com/scribe.php" ] ,
  "infoseek" : [ "infoseek.png" , "http://www.infoseek.jp/" ] ,
  "i.scribe" : [ "i.scribe.png" , "http://www.memecode.com/scribe.php" ] ,
  "iplanet" : [ "iplanet.png" , "http://www.sun.com/" ] ,
  "inxmail" : [ "inxmail.png" , "http://www.inxmail.de/" ] ,
  "intouch" : [ "intouch.png" , "http://intouchhometours.com/" ] ,
  "insuite" : [ "insuite.png" , "http://www.insuite.jp/" ] ,
  "ifwiset" : [ "iset.png" , "http://www.iset.com.br/" ] ,
  "icewarp" : [ "icewarp.png" , "http://www.icewarp.com/" ] ,
  "icedove" : [ "icedove.png" , "http://packages.debian.org/stable/mail/icedove" ] ,
  "inmail" : [ "inmail_cz.png" , "http://www.inmail.cz/" ] ,
  "imail/" : [ "gnu.png" , "http://www.gnu.org/software/mit-scheme/" ] ,
  "igmail" : [ "igmail.png" , "http://webmail.ig.com.br/" ] ,
  "i-land" : [ "i-land.png" , "http://www.iland.net/" ] ,
  "ispcp" : [ "ispcp.png" , "http://www.isp-control.net/" ] ,
  "impaq" : [ "impaq.png" , "http://www.impaqgroup.com/" ] ,
  "imho/" : [ "roxen.png" , "http://www.lysator.liu.se/~stewa/IMHO/" ] ,
  "imho " : [ "roxen.png" , "http://www.lysator.liu.se/~stewa/IMHO/" ] ,
  "is24" : [ "is24.png" , "http://www.immobilienscout24.de/" ] ,
  "imp/" : [ "horde.png" , "http://www.horde.org/imp/" ] ,
}

==> icedove-dispmua_1.6.4.3.orig.tar.gz: icedove-dispmua-1.6.4.3/chrome/content/data-69.js <==
dispMUA.arDispMUAAllocation["i"] =
{
  "interfejs www nowej poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "interfejs www poczty wirtualnej polski" : [ "wp_pl.png" , "http://www.wp.pl/" ] ,
  "ibm lotus domino access for ms outlook" : [ "domino_outlook.png" , "http://www-306.ibm.com/software/lotus/support/damo/use.html" ] ,
  "internetpost for active platform" : [ "internetpost.png" , "http://www.hitachi-to.co.jp/prod/prod_2/inter/ip4ap/overview.html" ] ,
  "interfejs www poczty orange" : [ "orange.png" , "http://www.orange.pl/" , "orange.pl" ] ,
  "internet messaging program" : [ "horde.png" , "http://www.horde.org/imp/" ] ,
  "iskoninternet webmail" : [ "iskon.png" , "http://webmail.iskon.hr/" ] ,
  "internet mail service" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "ipx-manager via php" : [ "ipxserver.png" , "http://www.ipx-server.de/" ] ,
  "ibforums php mailer" : [ "ipb.png" , "http://www.invisionpower.com/" ] ,
  "internet fax, mgcs" : [ "panafax.png" , "http://www.panasonic.com/business/office/pro_fax.asp" ] ,
  "infinite responder" : [ "infinite-responder.png" , "http://infinite.ibasics.biz/" ] ,
  "ics smtp component" : [ "ics.png" , "http://www.overbyte.be/" ] ,
  "i-effectmailclient" : [ "i-effect_de.png" , "http://www.i-effect.de/" ] ,
  "internet anywhere" : [ "internet-anywhere.png" , "http://www.tnsoft.de/" ] ,
  "inside-intermedia" : [ "inside-intermedia.png" , "http://www.inside-intermedia.de/" ] ,
  "i-base newsletter" : [ "i-base.png" , "http://www.i-base.net/" ] ,
  "intos electronic" : [ "intos-electronic.png" , "http://www.intos.de/" ] ,
  "inmail by insite" : [ "inmailinsite.png" , "http://inmail.insite.com.br/" ] ,
  "inbox.lv webmail" : [ "inbox.png" , "http://www.inbox.lv/" ] ,
  "inbox.lt webmail" : [ "inbox.png" , "http://www.inbox.lt/" ] ,
  "i.ua mail system" : [ "i_ua.png" , "http://www.i.ua/" ] ,
  "ixmailer (ken!)" : [ "ken.png" , "http://www.avm.de/" ] ,
  "ipb php mailer" : [ "ipb.png" , "http://www.invisionpower.com/" ] ,
  "ieurop webmail" : [ "ieurop_net.png" , "http://www.ieurop.net/" ] ,
  "inwise mailer" : [ "inwise.png" , "http://www.inwise.com/" ] ,
  "interact24.de" : [ "interact24_de.png" , "http://interact24.de/" ] ,
  "inteligo-smtp" : [ "inteligo.png" , "http://www.inteligo.pl/" ] ,
  "inmail insite" : [ "inmailinsite.png" , "http://inmail.insite.com.br/" ] ,
  "immsgmassmail" : [ "software_com.png" , "http://www.software.com/" ] ,
  "icompass-mail" : [ "icompass.png" , "http://www.identitycompass.com/" ] ,
  "i-soft/i-tems" : [ "i_tems.png" , "http://www.i-soft-net.de/" ] ,
  "i-soft i-tems" : [ "i_tems.png" , "http://www.i-soft-net.de/" ] ,
  "it&o-versand" : [ "itando.png" , "http://www.itando.net/versand.htm" ] ,
  "intellimerge" : [ "intelli.png" , "http://www.intellisw.com/intellimerge/" ] ,
  "ihug webmail" : [ "ihug.png" , "http://webmail.ihug.co.nz/" ] ,
  "ientrymailer" : [ "ientrymailer.png" ] ,
  "iphone mail" : [ "apple_iphone.png" , "http://www.apple.com/" ] ,
  "incredimail" : [ "incredimail.png" , "http://www.incredimail.com/" ] ,
  "ipilum.com" : [ "ipilum_com.png" , "http://www.ipilum.com/" ] ,
  "infomaniak" : [ "infomaniak.png" , "http://www.infomaniak.ch/" ] ,
  "immonet.de" : [ "immonet_de.png" , "http://www.immonet.de/" ] ,
  "igraalmail" : [ "igraal.png" , "http://fr.igraal.com/" ] ,
  "ibr-online" : [ "ibr-online.png" , "http://www.ibr-online.de/" ] ,
  "irfanview" : [ "irfanview.png" , "http://www.irfanview.net/" ] ,
  "ipod mail" : [ "apple_ipodtouch.png" , "http://www.apple.com/" ] ,
  "iofficev3" : [ "iofficev3.png" , "http://www.neo.co.jp/ioffice/" ] ,
  "intellect" : [ "intellect.png" , "http://www.chaossoftware.com/intellect.asp" ] ,
  "indexsoft" : [ "indexsoft.png" , "http://www.indexsoft.com/" ] ,
  "incomedia" : [ "incomedia.png" , "http://www.incomedia.it/" ] ,
  "inbox.com" : [ "inbox_com.png" , "http://www.inbox.com/" ] ,
  "ilohamail" : [ "iloha_mail.png" , "http://ilohamail.org/" ] ,
  "ik mailer" : [ "ikmultimedia.png" , "http://www.ikmultimedia.com/" ] ,
  "ibwebmail" : [ "infobox_ru.png" , "http://www.infobox.ru/" ] ,
  "ironmail" : [ "securecomputing.png" , "http://www.ciphertrust.com/products/cclass/" ] ,
  "ippbxsrv" : [ "telekom.png" , "http://www.telekom.de/" ] ,
  "intouch/" : [ "claros_intouch.png" , "http://www.claros.org/" ] ,
  "inscribe" : [ "inscribe.png" , "http://www.memecode.com/scribe.php" ] ,
  "infoseek" : [ "infoseek.png" , "http://www.infoseek.jp/" ] ,
  "imailist" : [ "imailist.png" , "http://imailistproj.sourceforge.net/" ] ,
  "ibizmail" : [ "yahoo_ibizmail.png" , "http://www.ibizmail.net/" ] ,
  "i.scribe" : [ "i.scribe.png" , "http://www.memecode.com/scribe.php" ] ,
  "iplanet" : [ "iplanet.png" , "http://www.sun.com/" ] ,
  "inxmail" : [ "inxmail.png" , "http://www.inxmail.de/" ] ,
  "intouch" : [ "intouch.png" , "http://intouchhometours.com/" ] ,
  "insuite" : [ "insuite.png" , "http://www.insuite.jp/" ] ,
  "in-mail" : [ "in-mail_ru.png" , "http://in-mail.ru/" ] ,
  "imoxion" : [ "imoxion.png" , "http://www.imoxion.com/" ] ,
  "ifwiset" : [ "iset.png" , "http://www.iset.com.br/" ] ,
  "icewarp" : [ "icewarp.png" , "http://www.icewarp.com/" ] ,
  "icedove" : [ "icedove.png" , "http://packages.debian.org/stable/mail/icedove" ] ,
  "inmail" : [ "inmail_cz.png" , "http://www.inmail.cz/" ] ,
  "imail/" : [ "gnu.png" , "http://www.gnu.org/software/mit-scheme/" ] ,
  "im2001" : [ "im2001.png" , "http://www.info2000.biz/public/Globalization/it-IT/Prodotti/Software/im2001/im2001.aspx" ] ,
  "igmail" : [ "igmail.png" , "http://webmail.ig.com.br/" ] ,
  "i-land" : [ "i-land.png" , "http://www.iland.net/" ] ,
  "ispcp" : [ "ispcp.png" , "http://www.isp-control.net/" ] ,
  "impaq" : [ "impaq.png" , "http://www.impaqgroup.com/" ] ,
  "imho/" : [ "roxen.png" , "http://www.lysator.liu.se/~stewa/IMHO/" ] ,
  "imho " : [ "roxen.png" , "http://www.lysator.liu.se/~stewa/IMHO/" ] ,
  "ikiss" : [ "ikiss.png" , "http://www.ikiss.de/" ] ,
  "is24" : [ "is24.png" , "http://www.immobilienscout24.de/" ] ,
  "imp/" : [ "horde.png" , "http://www.horde.org/imp/" ] ,
}
